summaryrefslogtreecommitdiffstats
path: root/kbruch/src/resultwidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /kbruch/src/resultwidget.cpp
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbruch/src/resultwidget.cpp')
-rw-r--r--kbruch/src/resultwidget.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kbruch/src/resultwidget.cpp b/kbruch/src/resultwidget.cpp
index 7f493408..853e73da 100644
--- a/kbruch/src/resultwidget.cpp
+++ b/kbruch/src/resultwidget.cpp
@@ -18,14 +18,14 @@
#include "resultwidget.h"
#include "resultwidget.moc"
/* these includes are needed for Qt support */
#include <tqpainter.h>
#include "settingsclass.h"
-ResultWidget::ResultWidget(TQWidget * parent = 0, const char * name = 0,
+ResultWidget::ResultWidget(TQWidget * tqparent = 0, const char * name = 0,
const ratio para_result = *new ratio()) :
- FractionBaseWidget(parent, name), m_result(para_result)
+ FractionBaseWidget(tqparent, name), m_result(para_result)
{
#ifdef DEBUG
kdDebug() << "constructor ResultWidget" << endl;
@@ -58,7 +58,7 @@ void ResultWidget::paintEvent(TQPaintEvent* /* p_paintEvent */)
paint.setFont(m_font);
// set the pen for painting
- TQPen pen(Qt::SolidLine);
+ TQPen pen(TQt::SolidLine);
pen.setWidth(0);
paint.setPen(pen);
@@ -73,7 +73,7 @@ void ResultWidget::paintEvent(TQPaintEvent* /* p_paintEvent */)
paintMiddle(paint, TQString("="), old_x, fm, m_colorOperation);
paintRatio(paint, m_result, old_x, fm, false);
- if (SettingsClass::showSpecialRatioNotation() == true && QABS(m_result.numerator()) >= QABS(m_result.denominator()))
+ if (SettingsClass::showSpecialRatioNotation() == true && TQABS(m_result.numerator()) >= TQABS(m_result.denominator()))
{
// result as mixed number
paintMiddle(paint, TQString("="), old_x, fm, m_colorOperation);
@@ -18,14 +18,14 @@
#include "resultwidget.h"
#include "resultwidget.moc"
-/* these includes are needed for Qt support */
+/* these includes are needed for TQt support */
#include <tqpainter.h>
#include "settingsclass.h"